You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2013/01/30 00:38:27 UTC

svn commit: r1440218 - /subversion/trunk/subversion/libsvn_wc/conflicts.c

Author: julianfoad
Date: Tue Jan 29 23:38:26 2013
New Revision: 1440218

URL: http://svn.apache.org/viewvc?rev=1440218&view=rev
Log:
* subversion/libsvn_wc/conflicts.c
  (resolve_conflict_on_node): Clarify some notes I added in r1440193.

Modified:
    subversion/trunk/subversion/libsvn_wc/conflicts.c

Modified: subversion/trunk/subversion/libsvn_wc/conflicts.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/conflicts.c?rev=1440218&r1=1440217&r2=1440218&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/conflicts.c (original)
+++ subversion/trunk/subversion/libsvn_wc/conflicts.c Tue Jan 29 23:38:26 2013
@@ -2261,8 +2261,10 @@ svn_wc__read_conflicts(const apr_array_h
    and clearing the conflict filenames from the entry.  The latter needs to
    be done whether or not the conflict files exist.
 
-   ### This func combines *resolving* and *marking as resolved*.
-   ### Resolving is shared between this func and its caller -- seems wrong.
+   ### This func combines *resolving* and *marking as resolved* -- seems poor.
+
+   ### Resolving is shared between this func and its caller
+       'conflict_status_walker()' -- seems poor.
 
    LOCAL_ABSPATH in DB is the path to the item to be resolved.
    RESOLVE_TEXT, RESOLVE_PROPS and RESOLVE_TREE are TRUE iff text, property
@@ -2270,9 +2272,15 @@ svn_wc__read_conflicts(const apr_array_h
 
    If this call marks any conflict as resolved, set *DID_RESOLVE to true,
    else to false.
-   ### If asked to resolve a text or prop conflict, only set *DID_RESOLVE
-       to true if a conflict marker file was present.
+   If asked to resolve a text or prop conflict, only set *DID_RESOLVE
+   to true if a conflict marker file was present, because if no marker
+   file was present then the conflict is considered to be marked as
+   resolved already.
    ### If asked to resolve a tree conflict, always set *DID_RESOLVE to true.
+       This would make sense if 'resolve_tree' is only requested when
+       there is in fact a tree conflict to be resolved, but, for
+       consistency with text & prop conflicts, the code should probably
+       say "if (resolve_tree && tree_conflicted) *did_resolve = TRUE".
 
    See svn_wc_resolved_conflict5() for how CONFLICT_CHOICE behaves.
 */